@@ -53,7 +53,7 @@ write_out_password (const char *password)
     line = g_strdup_printf ("%s:%s:%s\n", USER, REALM, ascii_digest);
     g_free (ascii_digest);
 
-    filename = g_build_filename (g_get_home_dir (), ".gnome2/user-share/passwd", NULL);
+    filename = g_build_filename (g_get_user_config_dir (), "user-share", "passwd", NULL);
 
     file = fopen (filename, "w");
     if (file != NULL) {
@@ -478,9 +478,6 @@ main (int argc, char *argv[])
     accept_obexpush_combo = GTK_WIDGET (gtk_builder_get_object (builder, "accept_obexpush_combo"));
     notify_received_obexpush_check = GTK_WIDGET (gtk_builder_get_object (builder, "notify_received_obexpush_check"));
 
-    //FIXME implement notifications
-    gtk_widget_hide (notify_received_obexpush_check);
-
     store = gtk_list_store_new (1, G_TYPE_STRING);
     gtk_combo_box_set_model (GTK_COMBO_BOX (password_combo),
 			     GTK_TREE_MODEL (store));
